
# These R codes are used to produce the results and figures presented in the article
# "Reconciling the Evidence of Card and Krueger (1994) and Neumark and Wascher (2000)"
# Card and Krueger (CK) data are available both in http://www.irs.princeton.edu/Links/MinimumWage.php 
# and http://econ-www.mit.edu/faculty/angrist/data1/mhe/card (visited 06.05.2011)

# In order to get the upper bounds for the employment effects choose:
# "LOWER BOUNDS FOR COUNTERFACTUALS AND UPPER BOUNDS FOR EMPLOYMENT EFFECTS"
# whenever possible.

# In order to get the lower bounds for the employment effects choose:
# "UPPER BOUNDS FOR COUNTERFACTUALS AND LOWER BOUNDS FOR EMPLOYMENT EFFECTS"
# whenever possible.


	##############################
	# 1. THE RESULTS FOR CK DATA #
	##############################


	# Picking up the data and constructing the variables

Data<-read.table("public.dat", header=FALSE, dec=".", na.strings=".")
SHEET<-Data[,1]; CHAIN<-Data[,2]; CO_OWNED<-Data[,3]; STATE<-Data[,4]
# Dummies for location:
SOUTHJ<-Data[,5]; CENTRALJ<-Data[,6]; NORTHJ<-Data[,7]; PA1<-Data[,8]; PA2<-Data[,9]; SHORE<-Data[,10]; NJ<-SOUTHJ+CENTRALJ+NORTHJ
# Variables of the first interview:
NCALLS<-Data[,11]; EMPFT<-Data[,12]; EMPPT<-Data[,13]; NMGRS<-Data[,14]; WAGE_ST<-Data[,15]; INCTIME<-Data[,16]; FIRSTINC<-Data[,17]; BONUS<-Data[,18]; PCTAFF<-Data[,19]; MEALS<-Data[,20]; OPEN<-Data[,21]; HRSOPEN<-Data[,22]; PSODA<-Data[,23]; PFRY<-Data[,24]; PENTREE<-Data[,25]; NREGS<-Data[,26]; NREGS11<-Data[,27]
# Variables of the second interview:
TYPE2<-Data[,28]; STATUS2<-Data[,29]; DATE2<-Data[,30]; NCALLS2<-Data[,31]; EMPFT2<-Data[,32]; EMPPT2<-Data[,33]; NMGRS2<-Data[,34]; WAGE_ST2<-Data[,35]; INCTIME2<-Data[,36]; FIRSTINC2<-Data[,37]; SPECIAL2<-Data[,38]; MEALS2<-Data[,39]; OPEN2R<-Data[,40]; HRSOPEN2<-Data[,41]; PSODA2<-Data[,42]; PFRY2<-Data[,43]; PENTREE2<-Data[,44]; NREGS2<-Data[,45]; NREGS112<-Data[,46]

	# Removing the observations with missing values for employment variables (like CK)

# First interview:
empft<-EMPFT[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; emppt<-EMPPT[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; nmgrs<-NMGRS[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; wage_st<-WAGE_ST[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; nj<-NJ[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; halfemppt<-emppt/2; FTE<-empft+nmgrs+halfemppt
# Second interview:
empft2<-EMPFT2[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; emppt2<-EMPPT2[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; nmgrs2<-NMGRS2[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; wage_st2<-WAGE_ST2[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; halfemppt2<-emppt2/2; FTE2<-empft2+nmgrs2+halfemppt2

	# Construction of treatment and control groups before and after

Y00<-FTE[nj=="0"]; Y01<-FTE2[nj=="0"]; Y10<-FTE[nj=="1"]; Y11<-FTE2[nj=="1"]

	# Constructing the CIC counterfactual values for employment:

# First using the (ecdf) macro to get the empirical cumulative distribution functions F00, F01, F10 and F11.
F00<-ecdf(Y00); F01<-ecdf(Y01); F10<-ecdf(Y10); F11<-ecdf(Y11)

# Second, constructing the inverse function for the cumulative distribution function F01. 
# Note that for the continuous variable case the inverse function must be continuous from left, 
# unlike the original empirical cumulative distribution. This is in order to satisfy the restriction in 
# equation 35 in Athey and Imbens (AI, 2006). For the discrete variable these correspond to the 
# upper bounds of the counterfactual and thus the lower bounds for the empoyment effects.
# For the lower bounds of the counterfactual the inverse function must be continuous from right, see eq.24 in AI.

min(Y01); add<-cbind(0,Y01); Y01.ord<-c(sort(add))
# Removing the ones with the same value (if some)
Y01.ord<-unique(Y01.ord)
# Calculating the percentiles for all but the biggest value.
p<-F01(Y01.ord)[-length(Y01.ord)]
# Calculating the inverse function for F01 using the step function and making the inverse function 
# to be continuous from the left.
#F01.inv<-stepfun(p,Y01.ord,right=FALSE,f=1) # UPPER BOUNDS FOR COUNTERFACTUALS AND LOWER BOUNDS FOR EMPLOYMENT EFFECTS
F01.inv<-stepfun(p,Y01.ord,right=TRUE,f=1) # LOWER BOUNDS FOR COUNTERFACTUALS AND UPPER BOUNDS FOR EMPLOYMENT EFFECTS

# Third, constructing the terms for the latter of the two sums in equation 36 in AI by first applying 
# the ecdf F00 for all the observations in Y10 and then applying the inverse of the ecdf F01 
# for the terms appearing from F00(Y10).

Y_10<-F00(Y10); Y__10<-F01.inv(Y_10) #Y__10

	# Calculating the employment effects for each of the restaurants as well as the CIC average employment effect

TE<-Y11-Y__10; Tau<-mean(Y11)-mean(Y__10)

	# Calculating the DID estimate for the average effect (corresponds to the one reported for balanced sample in table 3 in CK)

DID<-mean(Y11)-mean(Y10)-(mean(Y01)-mean(Y00))

funcY__10<-ecdf(Y__10)

##############################################################################
# Graphs for Figure 1 (construction of the counterfactual employment levels) #
##############################################################################

	# ECDF for period 0 Pennsylvania (upper left hand side graph):

par(mfrow=c(1,1)); tt <- seq(0,100, by=0.5)
plot(tt,F00(tt), xlim=c(0,68), ylim=c(0,1), ylab="Pennsylvania", xlab="FTE employment", pch="*", type="l"); text(31,0.6,"early 1992")
axis(2, at=0.90)
y1<-seq(1:120); y2<-y1-20; y<-y2*F00(40)/100; x<-rep(40, len=120); lines(x,y); z1<-rep(F00(40), len=130); z2a<-seq(1:130); z2b<-z2a-10; z2<-z2b/3; lines(z2,z1)

	# ECDF for period 0 New Jersey (upper right hand side graph):

plot(tt,F10(tt), xlim=c(0,68), ylim=c(0,1), ylab="New Jersey", xlab="FTE employment", pch="*", type="l"); text(31,0.6,"early 1992")
axis(2, at=0.90)
y1<-seq(1:120); y2<-y1-20; y<-y2*F10(40)/100; x<-rep(40, len=120); lines(x,y); z1<-rep(F10(40), len=130); z2a<-seq(1:130); z2b<-z2a-10; z2<-z2b/3; lines(z2,z1)

	# ECDF's for period 0 and 1 in Pennsylvania (lower left hand side graph):

plot(tt,F00(tt), xlim=c(0,68), ylim=c(0,1), ylab="Pennsylvania", xlab="FTE employment", pch="*", type="l"); points(tt,F01(tt), col="red", pch="*", type="l"); text(28,0.5,"early 1992"); text(20,0.8,"late 1992")
axis(1, at=34)
y1<-seq(1:120); y2<-y1-20; y<-y2*F00(40)/100; x<-rep(40, len=120); lines(x,y); y1<-seq(1:120); y2<-y1-20; y<-y2*F01(34)/100; x<-rep(34, len=120); lines(x,y); y<-rep(F00(40), len=121); x1<-seq(1:1:121); x2<-x1-1; x3<-x2/20; x<-x3+34; lines(x,y)

	# ECDF for New Jersey period 0 and the counterfactual (lower right hand side graph):

plot(tt,F10(tt), xlim=c(0,68), ylim=c(0,1), ylab="New Jersey", xlab="FTE employment", pch="*", type="l"); points(tt,funcY__10(tt), col="blue", pch=".", type="s"); text(17,0.75,"early 1992"); text(20,0.9,"counterfactual")
axis(1, at=34)
y1<-seq(1:120); y2<-y1-20; y<-y2*F10(40)/100; x<-rep(40, len=120); lines(x,y); x<-rep(34, len=120); lines(x,y); y<-rep(F10(40), len=121); x1<-seq(1:1:121); x2<-x1-1; x3<-x2/20; x<-x3+34; lines(x,y)

#########################################################################################
# Figure 2 (counterfactual employment level as a function of original employment level) #
#########################################################################################

# Counterfactual values as a function of period 0 FTE employment
a1<-cbind(0,Y10); b1<-cbind(0,Y__10); a<-sort(a1); b<-sort(b1); plot(a,b, xlim=c(0,68), ylim=c(0,max(b)), ylab="counterfactual employment", xlab="FTE employment", pch="*", type="l")

######################################################################################
# Figure 3 (ECDF for New Jersey after the increase together with the counterfactual) #
######################################################################################

plot(tt,F11(tt), xlim=c(0,68), ylim=c(0,1), ylab="New Jersey", xlab="FTE employment", pch="*", type="l", col="red"); points(tt,funcY__10(tt), col="blue", pch=".", type="s"); text(28,0.55,"late 1992"); text(19,0.88,"counterfactual")

######################################################################################################################
# Left hand side graph of Figure 6 and Figure 4 (The employment effects for individual fast-food restaurants, (DID   #
# and CIC) average employment effects and the conditional average employment effects (with 301 New Jersey obs.))     #
######################################################################################################################

# For 8 (NJ) observations we do not have the identification condition satisfied - for these the period 0 obs. Y10 
# are not in the domain of Y00. These are excluded when calculating the employment effects.
INDsmall<-Y10<min(Y00); INDbig<-Y10>max(Y00); IND<-INDsmall+INDbig; Y11id<-Y11[IND=="0"]; Y__10id<-Y__10[IND=="0"]; Y10id<-Y10[IND=="0"]

	# Calculating the employment effects for each of the observations and the average employment effects by both CIC and DID estimators

TEid<-Y11id-Y__10id; Tau<-mean(Y11id)-mean(Y__10id); DID<-mean(Y11id)-mean(Y10id)-(mean(Y01)-mean(Y00)); Tau; DID

ii<-order(Y10id,TEid); Q<-rbind(Y10id,TEid)[,ii]; TEid.ord<-Q[2*1:length(TEid)]; Y10id.ord<-Q[2*1:length(Y10id)-1]
m<-min(TEid); M<-max(TEid); mm<-max(M,-m)
# UPPER BOUNDS FOR COUNTERFACTUALS AND LOWER BOUNDS FOR EMPLOYMENT EFFECTS:
#plot(Y10id,TEid,ylim=c(-mm,mm),pch="*", ylab="Employment effect", xlab="FTE employment",xlim=c(2,55)); abline(0,0); abline(Tau,0, lty="dashed"); abline(DID,0, lty="dotted"); lines(cbind(Y10id.ord,lowess(TEid.ord)$y),col="red", lwd=2); text(50,4,"DID=2.72"); text(50,1.5,"CIC=0.90"); text(45,-2.5,"Conditional average");axis(1, at=24);x<-rep(24,5); y<-cbind(0,-10,-20,-30,-40); lines(x,y,type="l")
# LOWER BOUNDS FOR COUNTERFACTUALS AND UPPER BOUNDS FOR EMPLOYMENT EFFECTS:
plot(Y10id,TEid,ylim=c(-mm,mm),pch="*", ylab="Employment effect", xlab="FTE employment",xlim=c(2,55)); abline(0,0); abline(Tau,0, lty="dashed"); abline(DID,0, lty="dotted"); lines(cbind(Y10id.ord,lowess(TEid.ord)$y),col="red", lwd=2); text(50,4,"DID=2.72"); text(50,1.5,"CIC=1.70"); text(45,-2,"Conditional average")

	# Calculating the standard error for the average employment effect

aver<-function(x) sum(x)/length(x); boot<-numeric(100000); for (i in 1:100000) boot[i] <- aver(sample(TEid, replace=T)); sqrt(var(boot))

#######################################################################################################
# Lower left hand side and upper left hand side graph of Figure 7 (estimation with control variables) #
#######################################################################################################

	# First calculating the parametric part (that takes the controls into account)

empftX<-EMPFT[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; empptX<-EMPPT[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; nmgrsX<-NMGRS[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; wage_stX<-WAGE_ST[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; njAX<-NJ[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; pa1X<-PA1[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; centraljX<-CENTRALJ[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; northjX<-NORTHJ[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]
empft2X<-EMPFT2[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; emppt2X<-EMPPT2[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; nmgrs2X<-NMGRS2[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; wage_st2X<-WAGE_ST2[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]
halfempptX<-empptX/2; halfemppt2X<-emppt2X/2; FTEX<-empftX+nmgrsX+halfempptX; FTE2X<-empft2X+nmgrs2X+halfemppt2X
chainBX<-CHAIN[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; chainX<-c(chainBX,chainBX)
co_ownedBX<-CO_OWNED[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; co_ownedX<-c(co_ownedBX,co_ownedBX)

INDsmall<-FTEX<min(Y00); INDbig<-FTEX>max(Y00); IND<-INDsmall+INDbig

empft<-empftX[IND=="0"]; emppt<-empptX[IND=="0"]; nmgrs<-nmgrsX[IND=="0"]; wage_st<-wage_stX[IND=="0"]; njA<-njAX[IND=="0"]; pa1<-pa1X[IND=="0"]; centralj<-centraljX[IND=="0"]; northj<-northjX[IND=="0"]
empft2<-empft2X[IND=="0"]; emppt2<-emppt2X[IND=="0"]; nmgrs2<-nmgrs2X[IND=="0"]; wage_st2<-wage_st2X[IND=="0"]
halfemppt<-halfempptX[IND=="0"]; halfemppt2<-halfemppt2X[IND=="0"]; FTE<-FTEX[IND=="0"]; FTE2<-FTE2X[IND=="0"]
chainB<-chainBX[IND=="0"]; chain<-chainX[IND=="0"]; co_ownedB<-co_ownedBX[IND=="0"]; co_owned<-co_ownedX[IND=="0"]

fte<-c(FTE,FTE2); nj<-c(njA,njA); wave2<-c(rep(0,len=376),rep(1,len=376)); Dnj1<-nj=="1"&wave2=="0"; nj1<-Dnj1*Dnj1; Dnj2<-nj=="1"&wave2=="1"; nj2<-Dnj2*Dnj2; DP1<-nj=="0"&wave2=="0"; p1<-DP1*DP1; DP2<-nj=="0"&wave2=="1"; p2<-DP2*DP2; C1<-chain=="1"; c1<-C1*C1; C2<-chain=="2"; c2<-C2*C2; C3<-chain=="3"; c3<-C3*C3; C_O<-co_owned=="1"; co<-C_O*C_O; paA<-c(pa1,pa1); central<-c(centralj,centralj); north<-c(northj,northj)

#summary(lm(fte~nj1+nj2+p1+p2+c1+c2+c3+co+paA+central+north-1))

	# Second, calculating the CIC estimates for the adjusted FTE employment levels (that arise from the parametric estimation).

empftX<-EMPFT[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; empptX<-EMPPT[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; nmgrsX<-NMGRS[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; wage_stX<-WAGE_ST[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; njX<-NJ[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; pa1X<-PA1[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; centraljX<-CENTRALJ[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; northjX<-NORTHJ[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; halfempptX<-empptX/2; FTEX<-empftX+nmgrsX+halfempptX
empft2X<-EMPFT2[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; emppt2X<-EMPPT2[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; nmgrs2X<-NMGRS2[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; wage_st2X<-WAGE_ST2[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; halfemppt2X<-emppt2X/2; FTE2X<-empft2X+nmgrs2X+halfemppt2X

chainX<-CHAIN[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; c1X<-chainX=="1"; c2X<-chainX=="2"; c3X<-chainX=="3"
co_ownedX<-CO_OWNED[!is.na(EMPFT) & !is.na(EMPPT) & !is.na(NMGRS) & !is.na(EMPFT2) & !is.na(EMPPT2) & !is.na(NMGRS2)]; coX<-co_ownedX=="1"

INDsmall<-FTEX<min(Y00); INDbig<-FTEX>max(Y00); IND<-INDsmall+INDbig

empft<-empftX[IND=="0"]; emppt<-empptX[IND=="0"]; nmgrs<-nmgrsX[IND=="0"]; wage_st<-wage_stX[IND=="0"]; nj<-njX[IND=="0"]; pa1<-pa1X[IND=="0"]; centralj<-centraljX[IND=="0"]; northj<-northjX[IND=="0"]; halfemppt<-halfempptX[IND=="0"]; FTE<-FTEX[IND=="0"]; empft2<-empft2X[IND=="0"]; emppt2<-emppt2X[IND=="0"]; nmgrs2<-nmgrs2X[IND=="0"]; wage_st2<-wage_st2X[IND=="0"]; halfemppt2<-halfemppt2X[IND=="0"]; FTE2<-FTE2X[IND=="0"]
chain<-chainX[IND=="0"]; c1<-c1X[IND=="0"]; c2<-c2X[IND=="0"]; c3<-c3X[IND=="0"]; co_owned<-co_ownedX[IND=="0"]; co<-coX[IND=="0"]

FTEmod<-FTE-1.2719*c1+8.8083*c2+0.9374*c3+1.0382*co-0.7386*pa1-2.8089*centralj-3.6963*northj
FTEmod2<-FTE2-1.2719*c1+8.8083*c2+0.9374*c3+1.0382*co-0.7386*pa1-2.8089*centralj-3.6963*northj

	# Constructing treatment and control groups before and after

Y00<-FTEmod[nj=="0"]; Y01<-FTEmod2[nj=="0"]; Y10<-FTEmod[nj=="1"]; Y11<-FTEmod2[nj=="1"]

	# Calculating the CIC estimates for the treatment effects on employment

# First using the (ecdf) macro to get the empirical cumulative distribution functions F00, F01, F10 and F11.
F00<-ecdf(Y00); F01<-ecdf(Y01); F10<-ecdf(Y10); F11<-ecdf(Y11)

# Second, constructing the inverse function for the cumulative distribution function F01.

add<-cbind(0,Y01); Y01.ord<-c(sort(add))
Y01.ord<-unique(Y01.ord)
p<-F01(Y01.ord)[-length(Y01.ord)]
#F01.inv<-stepfun(p,Y01.ord,right=FALSE,f=1) # UPPER BOUNDS FOR COUNTERFACTUALS AND LOWER BOUNDS FOR EMPLOYMENT EFFECTS
F01.inv<-stepfun(p,Y01.ord,right=TRUE,f=1) # LOWER BOUNDS FOR COUNTERFACTUALS AND UPPER BOUNDS FOR EMPLOYMENT EFFECTS

# Third, calculating the individual employment effects as well as average treatment effect

Y_10<-F00(Y10); Y__10<-F01.inv(Y_10); TE<-Y11-Y__10; Tau<-mean(Y11)-mean(Y__10)

	# Calculating the DID estimate for the average effect

DID<-mean(Y11)-mean(Y10)-(mean(Y01)-mean(Y00)); Tau; DID

funcY__10<-ecdf(Y__10)

ii<-order(Y10,TE); Q<-rbind(Y10,TE)[,ii]; TE.ord<-Q[2*1:length(TE)]; Y10.ord<-Q[2*1:length(Y10)-1]
m<-min(TE); M<-max(TE); mm<-max(M,-m); 
# UPPER BOUNDS FOR COUNTERFACTUALS AND LOWER BOUNDS FOR EMPLOYMENT EFFECTS:
#plot(Y10,TE,ylim=c(-mm,mm),pch="*", ylab="Employment effect", xlab="Adjusted FTE employment",xlim=c(2,55)); abline(0,0); abline(Tau,0, lty="dashed"); abline(DID,0, lty="dotted"); lines(cbind(Y10.ord,lowess(TE.ord)$y),col="red", lwd=2); text(50,4,"DID=2.72"); text(50,1.5,"CIC=1.58"); text(45,-4,"Conditional average")
# LOWER BOUNDS FOR COUNTERFACTUALS AND UPPER BOUNDS FOR EMPLOYMENT EFFECTS:
plot(Y10,TE,ylim=c(-mm,mm),pch="*", ylab="Employment effect", xlab="Adjusted FTE employment",xlim=c(2,55)); abline(0,0); abline(Tau,0, lty="dashed"); abline(DID,0, lty="dotted"); lines(cbind(Y10.ord,lowess(TE.ord)$y),col="red", lwd=2); text(50,4,"DID=2.72"); text(50,1.5,"CIC=2.63"); text(45,-4,"Conditional average")


	# Calculating the standard error for the average employment effect

aver<-function(x) sum(x)/length(x); boot<-numeric(100000); for (i in 1:100000) boot[i] <- aver(sample(TEid, replace=T)); sqrt(var(boot))



	##############################
	# 2. THE RESULTS FOR NW DATA #
	##############################

	
	# Picking up the data and constructing the variables

Data<-read.table("payroll.dat", header=FALSE, dec=".", na.strings=".")

# Wave 1:
indB <- is.na(Data[,4]); indC <- is.na(Data[,6]); indD <- indB + indC

# Wave2:
indB2 <- is.na(Data[,12]); indC2 <- is.na(Data[,14]); indD2 <- is.na(Data[,16]); indE2 <- indB2 + indC2 + indD2

Data[,2][is.na(Data[,2])] <- 0; Data[,4][is.na(Data[,4])] <- 0; Data[,6][is.na(Data[,6])] <- 0
Data[,12][is.na(Data[,12])] <- 0; Data[,14][is.na(Data[,14])] <- 0; Data[,16][is.na(Data[,16])] <- 0

	# Calculating the average hours

ahours<-(Data[,2]+Data[,4]+Data[,6])/(3-indD)
ahours2<-(Data[,10]+Data[,12]+Data[,14]+Data[,16])/(4-indE2)

	# Making the hours weekly hours

chain <- Data[,18]; biwkly <- Data[,22]; mnthly <- Data[,23]
BK <- chain=="1"; WE <- chain=="4"; RR <- chain=="3"; KFC <- chain=="2"
comp <- Data[,24]; notRR <- RR=="FALSE"; notCO <- comp=="0"

ahours0 <- ahours*(1-biwkly)*(1-mnthly)
ahoursA <- ahours*biwkly/2
ahoursB <- ahours*mnthly*notRR/(29/7)
ahoursC <- ahours*mnthly*RR*notCO/(29/7)
ahoursD <- ahours*mnthly*RR*comp/4

ahours02 <- ahours2*(1-biwkly)*(1-mnthly)
ahoursA2 <- ahours2*biwkly/2
ahoursB2 <- ahours2*mnthly*notRR/(30/7)
ahoursC2 <- ahours2*mnthly*RR*notCO/(30/7)
ahoursD2 <- ahours2*mnthly*RR*comp/4

Whours <- ahours0 + ahoursA + ahoursB + ahoursC + ahoursD
Whours2 <- ahours02 + ahoursA2 + ahoursB2 + ahoursC2 + ahoursD2

FTE <- Whours/35
FTE2 <- Whours2/35

PA <- Data[,19]; NJ <- Data[,20]

	# Taking a look at the observations with no-missing values for employment

FTEpa <- FTE*PA
FTEPA <- FTEpa[FTEpa!="0"]
length(FTEPA)
# 72
FTEnj <- FTE*NJ
FTENJ <- FTEnj[FTEnj!="0"]
length(FTENJ)
# 163

FTEpa2 <- FTE2*PA
FTEPA2 <- FTEpa2[FTEpa2!="0"]
length(FTEPA2)
# 71
FTEnj2 <- FTE2*NJ
FTENJ2 <- FTEnj2[FTEnj2!="0"]
length(FTENJ2)
# 159

# obs. 81 (NJ), 139 (NJ), 150 (NJ), 154 (NJ) and 166 (PA) missing in the second wave ->

	# Removing these from both waves (in order to use the observations that have non-missing values 
	# for employment neither in wave 1 nor in wave 2).

fte <- FTE[FTE2!="0"]
length(fte)
# 230
fte2 <- FTE2[FTE2!="0"]
nj <- NJ[FTE2!="0"]
pa <- PA[FTE2!="0"]

ftepa <- fte*pa
ftepa <- ftepa[ftepa!="0"]
length(ftepa)
# 71
ftenj <- fte*nj
ftenj <- ftenj[ftenj!="0"]
length(ftenj)
# 159

ftepa2 <- fte2*pa
ftepa2 <- ftepa2[ftepa2!="0"]
length(ftepa2)
# 71
ftenj2 <- fte2*nj
ftenj2 <- ftenj2[ftenj2!="0"]
length(ftenj2)
# 159

dftePA <- ftepa2-ftepa
dfteNJ <- ftenj2-ftenj

# ftepa, ftepa2, ftenj and ftenj2 have the non-missing values for the FTE employments 
# in waves 1 and 2 in New Jersey and Pennsylvania.

	# Here starts the CIC estimation (71 and 159 obs. - like in figures 1 and 2 in NW,
	# we use the observations with no missing values for employment)

	# Construction of treatment and control groups before and after

Y00<-ftepa; Y01<-ftepa2; Y10<-ftenj; Y11<-ftenj2

	# Constructing the CIC counterfactuals for the employment:

# First using the (ecdf) macro to get the empirical cumulative distribution functions F00, F01, F10 and F11.
F00<-ecdf(Y00); F01<-ecdf(Y01); F10<-ecdf(Y10); F11<-ecdf(Y11)

# Second, constructing the inverse function for the cumulative distribution function F01.
min(Y01); add<-cbind(0,Y01); Y01.ord<-c(sort(add))
# Removing the ones with the same value (if some)
Y01.ord<-unique(Y01.ord)
# Calculating the percentiles for all but the biggest value.
p<-F01(Y01.ord)[-length(Y01.ord)]
# Calculating the inverse function for F01 using the step function and making the inverse function to be continuous from the left.
F01.inv<-stepfun(p,Y01.ord,right=FALSE,f=1) # UPPER BOUNDS FOR COUNTERFACTUALS AND LOWER BOUNDS FOR EMPLOYMENT EFFECTS
#F01.inv<-stepfun(p,Y01.ord,right=TRUE,f=1) # LOWER BOUNDS FOR COUNTERFACTUALS AND UPPER BOUNDS FOR EMPLOYMENT EFFECTS

# Third, constructing the terms for the latter of the two sums in equation 36 in AI by first applying the ecdf F00 for all the observations in Y10 and 
# then applying the inverse of the ecdf F01 for the terms appearing from F00(Y10) and finally calculating the treatment effects for each of the observations and 
# averaging over the individual treatment effects to get the estimated average treatment effect
Y_10<-F00(Y10); Y__10<-F01.inv(Y_10) #Y__10; TE<-Y11-Y__10; Tau<-mean(Y11)-mean(Y__10)

	# Calculating the DID estimate for the effect of an increase in the minimum wage on employment (estimate that corresponds to balanced sample in table 3 in CK)

DID<-mean(Y11)-mean(Y10)-(mean(Y01)-mean(Y00))

funcY__10<-ecdf(Y__10)

######################################################################################################################
# Right hand side graph of Figure 6 and Figure 5 (The employment effects for individual fast-food restaurants, (DID  #
# and CIC) average employment effects and the conditional average employment effects (with 151 New Jersey obs.))     #
######################################################################################################################

# For 8 (NJ) observations we do not have the identification condition satisfied - for these the period 0 obs. Y10 are not in the domain of Y00 (3 small values and 5 big values). These are excluded when calculating the employment effects.
INDsmall<-Y10<min(Y00); INDbig<-Y10>max(Y00); IND<-INDsmall+INDbig; Y11id<-Y11[IND=="0"]; Y__10id<-Y__10[IND=="0"]; Y10id<-Y10[IND=="0"]

	# Calculating the employment effects for each of the observations and the average employment effects by both CIC and DID estimators

TEid<-Y11id-Y__10id; Tau<-mean(Y11id)-mean(Y__10id); DID<-mean(Y11id)-mean(Y10id)-(mean(Y01)-mean(Y00))

ii<-order(Y10id,TEid); Q<-rbind(Y10id,TEid)[,ii]; TEid.ord<-Q[2*1:length(TEid)]; Y10id.ord<-Q[2*1:length(Y10id)-1]

par(mfrow=c(1,1))

m<-min(TEid); M<-max(TEid); mm<-max(M,-m)
# UPPER BOUNDS FOR COUNTERFACTUALS AND LOWER BOUNDS FOR EMPLOYMENT EFFECTS:
plot(Y10id,TEid,ylim=c(-33.8663,33.8663),pch="*", ylab="Employment effect", xlab="FTE employment",xlim=c(2,52)); abline(0,0); abline(Tau,0, lty="dashed"); abline(DID,0, lty="dotted"); lines(cbind(Y10id.ord,lowess(TEid.ord)$y),col="red", lwd=2); text(39,-3,"CIC= -1.82"); text(39,-0.7,"DID= -0.59"); text(37.6,-9.6,"Conditional average");axis(1, at=14.4);x<-rep(14.4,5); y<-cbind(0,-10,-20,-30,-40); lines(x,y,type="l") # Lower Bound
# LOWER BOUNDS FOR COUNTERFACTUALS AND UPPER BOUNDS FOR EMPLOYMENT EFFECTS:
#plot(Y10id,TEid,ylim=c(-33.8663,33.8663),pch="*", ylab="Employment effect", xlab="FTE employment",xlim=c(6.5,35)); abline(0,0); abline(Tau,0, lty="dashed"); abline(DID,0, lty="dotted"); lines(cbind(Y10id.ord,lowess(TEid.ord)$y),col="red", lwd=2); text(33,-2.3,"CIC= -1.22"); text(27,-2.3,"DID= -0.59"); text(31,-7.5,"Conditional average") # Upper Bound

	# Calculating the standard error for the average employment effect

aver<-function(x) sum(x)/length(x); boot<-numeric(100000); for (i in 1:100000) boot[i] <- aver(sample(TEid, replace=T)); sqrt(var(boot))

#########################################################################################################
# Lower right hand side and upper right hand side graph of Figure 7 (estimation with control variables) #
#########################################################################################################

	# First calculating the parametric part (that takes the controls into account)

CHAIN <- Data[,18]
chainBX<-CHAIN[FTE2!="0"]; chainX<-c(chainBX,chainBX)
CO_OWNED <- Data[,24]
co_ownedBX<-CO_OWNED[FTE2!="0"]; co_ownedX<-c(co_ownedBX,co_ownedBX)

INDsmall<-fte<min(Y00); INDbig<-fte>max(Y00); IND<-INDsmall+INDbig

FTE<-fte[IND=="0"]; FTE2<-fte2[IND=="0"]
chainB<-chainBX[IND=="0"]; chain<-chainX[IND=="0"]; co_ownedB<-co_ownedBX[IND=="0"]; co_owned<-co_ownedX[IND=="0"]

fte<-c(FTE,FTE2); 
njA <- nj[IND=="0"]
Nj<-c(njA,njA);
wave2<-c(rep(0,len=222),rep(1,len=222)); 
Dnj1<-Nj=="1"&wave2=="0"; 
nj1<-Dnj1*Dnj1; 
Dnj2<-Nj=="1"&wave2=="1"; 
nj2<-Dnj2*Dnj2; 
DP1<-Nj=="0"&wave2=="0"; 
p1<-DP1*DP1;
DP2<-Nj=="0"&wave2=="1"; 
p2<-DP2*DP2; 
C1<-chain=="1"; 
c1<-C1*C1; 
C2<-chain=="2"; 
c2<-C2*C2; 
C3<-chain=="3"; 
c3<-C3*C3; 
C_O<-co_owned=="1"; 
co<-C_O*C_O; 

#summary(lm(fte~nj1+nj2+p1+p2+c1+c2+c3+co-1))

	# Second, calculating the CIC estimator for the adjusted FTE employment levels (that arise from the parametric estimation).

FTE <- Whours/35
FTE2 <- Whours2/35

PA <- Data[,19]; NJ <- Data[,20]

# obs. 81 (NJ), 139 (NJ), 150 (NJ), 154 (NJ) and 166 (PA) missing in the second wave ->

	# Removing these from both waves (in order to use the observations that have non-missing values 
	# for employment neither in wave 1 nor in wave 2).

fte <- FTE[FTE2!="0"]
length(fte)
# 230
fte2 <- FTE2[FTE2!="0"]
nj <- NJ[FTE2!="0"]
pa <- PA[FTE2!="0"]

ftepa <- fte*pa
ftepa <- ftepa[ftepa!="0"]
length(ftepa)
# 71
#hist(ftepa, breaks = 12, xlim=c(0,70))
ftenj <- fte*nj
ftenj <- ftenj[ftenj!="0"]
length(ftenj)
# 159
#hist(ftenj, breaks = 16, xlim=c(0,70))

ftepa2 <- fte2*pa
ftepa2 <- ftepa2[ftepa2!="0"]
length(ftepa2)
# 71
#hist(ftepa2, breaks = 12, xlim=c(0,70))
ftenj2 <- fte2*nj
ftenj2 <- ftenj2[ftenj2!="0"]
length(ftenj2)
# 159
#hist(ftenj2, breaks = 16, xlim=c(0,70))

# ftepa, ftepa2, ftenj and ftenj2 have the non-missing values for the FTE employments 
# in waves 1 and 2 in New Jersey and Pennsylvania.

Y00<-ftepa; Y01<-ftepa2; Y10<-ftenj; Y11<-ftenj2

FTE <- Whours/35
FTE2 <- Whours2/35

PA <- Data[,19]
NJ <- Data[,20]

fte <- FTE[FTE2!="0"]
length(fte)
# 230
fte2 <- FTE2[FTE2!="0"]
nj <- NJ[FTE2!="0"]
pa <- PA[FTE2!="0"]

CHAIN <- Data[,18]; chainBX<-CHAIN[FTE2!="0"]
CO_OWNED <- Data[,24]; co_ownedBX<-CO_OWNED[FTE2!="0"]
INDsmall<-fte<min(Y00); INDbig<-fte>max(Y00); IND<-INDsmall+INDbig
FTE<-fte[IND=="0"]; length(FTE); FTE2<-fte2[IND=="0"]; length(FTE2)
chain<-chainBX[IND=="0"]; length(chain); co_owned<-co_ownedBX[IND=="0"]; length(co_owned)
c1<-chain=="1"; c2<-chain=="2"; c3<-chain=="3"; length(c1)
co<-co_owned=="1"; length(co)
NJ <- nj[IND=="0"]

FTEmod<-FTE+3.1092*c1+7.7452*c2+2.9103*c3+2.3413*co
FTEmod2<-FTE2+3.1092*c1+7.7452*c2+2.9103*c3+2.3413*co

Y00<-FTEmod[NJ=="0"]; Y01<-FTEmod2[NJ=="0"]; Y10<-FTEmod[NJ=="1"]; Y11<-FTEmod2[NJ=="1"]

	# Constructing the CIC counterfactuals for employment

# First using the (ecdf) macro to get the empirical cumulative distribution functions F00, F01, F10 and F11.
F00<-ecdf(Y00); F01<-ecdf(Y01); F10<-ecdf(Y10); F11<-ecdf(Y11)

# Second, constructing the inverse function for the cumulative distribution function F01.

add<-cbind(0,Y01); Y01.ord<-c(sort(add))
# Removing the ones with the same value (if some)
Y01.ord<-unique(Y01.ord)
# Calculating the percentiles for all but the biggest value.
p<-F01(Y01.ord)[-length(Y01.ord)]
# Calculating the inverse function for F01 using the step function and making the inverse function to be continuous from the left.
#F01.inv<-stepfun(p,Y01.ord,right=FALSE,f=1) # UPPER BOUNDS FOR COUNTERFACTUALS AND LOWER BOUNDS FOR EMPLOYMENT EFFECTS
F01.inv<-stepfun(p,Y01.ord,right=TRUE,f=1) # LOWER BOUNDS FOR COUNTERFACTUALS AND UPPER BOUNDS FOR EMPLOYMENT EFFECTS

# Third, constructing the terms for the latter of the two sums in equation 36 in AI by first applying the ecdf F00 for all the observations in Y10 and 
# then applying the inverse of the ecdf F01 for the terms appearing from F00(Y10) and finally calculating the treatment effects for each of the observations and 
# averaging over the individual treatment effects to get the estimated average treatment effect
Y_10<-F00(Y10); Y__10<-F01.inv(Y_10); TE<-Y11-Y__10; Tau<-mean(Y11)-mean(Y__10)

	# Calculating the DID estimate for the effect of an increase in the minimum wage on employment

DID<-mean(Y11)-mean(Y10)-(mean(Y01)-mean(Y00))

funcY__10<-ecdf(Y__10)

ii<-order(Y10,TE); Q<-rbind(Y10,TE)[,ii]; TE.ord<-Q[2*1:length(TE)]; Y10.ord<-Q[2*1:length(Y10)-1]

# UPPER BOUNDS FOR COUNTERFACTUALS AND LOWER BOUNDS FOR EMPLOYMENT EFFECTS:
#m<-min(TE); M<-max(TE); mm<-max(M,-m); plot(Y10,TE,ylim=c(-33.8663,33.8663),pch="*", ylab="Employment effect", xlab="Adjusted FTE employment",xlim=c(9,35)); abline(0,0); abline(Tau,0, lty="dashed"); abline(DID,0, lty="dotted"); lines(cbind(Y10.ord,lowess(TE.ord)$y),col="red", lwd=2); text(32,-3,"CIC= -1.80"); text(32,-0.7,"DID= -0.59"); text(31,-12.5,"Conditional average") # Lower Bound
# LOWER BOUNDS FOR COUNTERFACTUALS AND UPPER BOUNDS FOR EMPLOYMENT EFFECTS:
m<-min(TE); M<-max(TE); mm<-max(M,-m); plot(Y10,TE,ylim=c(-33.8663,33.8663),pch="*", ylab="Employment effect", xlab="Adjusted FTE employment",xlim=c(9,35)); abline(0,0); abline(Tau,0, lty="dashed"); abline(DID,0, lty="dotted"); lines(cbind(Y10.ord,lowess(TE.ord)$y),col="red", lwd=2); text(33.5,-1.3,"CIC= -0.41"); text(27.5,-1.3,"DID= -0.59"); text(31,-10,"Conditional average") # Upper Bound

	# Calculating the standard error for the average employment effect

aver<-function(x) sum(x)/length(x); boot<-numeric(100000); for (i in 1:100000) boot[i] <- aver(sample(TEid, replace=T)); sqrt(var(boot))








